@@ -136,6 +136,8 @@ def domain_model_to_code(model: DomainModel, file_path: str, objectmodel: Object
                     metadata_params.append(f'description="{cls.metadata.description}"')
                 if cls.metadata.uri:
                     metadata_params.append(f'uri="{cls.metadata.uri}"')
+                if cls.metadata.icon:
+                    metadata_params.append(f'icon="{cls.metadata.icon}"')
 
                 if metadata_params:
                     metadata_str = f"Metadata({', '.join(metadata_params)})"
@@ -473,7 +475,9 @@ def agent_model_to_code(model: Agent, file_path: str):
         for intent in model.intents:
             f.write(f"{intent.name} = agent.new_intent('{intent.name}', [\n")
             for sentence in intent.training_sentences:
-                f.write(f"    '{sentence}',\n")
+                # Escape single quotes for Python string literal
+                escaped_sentence = sentence.replace('\\', '\\\\').replace("'", "\\'")
+                f.write(f"    '{escaped_sentence}',\n")
             f.write("])\n")
         f.write("\n")
         
